Bargad v1.0.1 Bargad.Log View Source

An append-only Log mode, backed by an underlying merkle tree. Once an entry has been accepted by the Log it cannot be changed or removed. In this mode, the Merkle tree is filled up from the left, giving a dense Merkle tree. Log mode has support for generation and verification of Consistency and Audit Proofs.

Link to this section Summary

Link to this section Functions

Link to this function build(tree_name, hash_function, backend, values) View Source
Link to this function consistency_proof(log, m) View Source
Link to this function new(tree_name, hash_function, backend) View Source
Link to this function verify_audit_proof(log, proof) View Source
Link to this function verify_consistency_proof(log, proof, old_root_hash) View Source