Bargad v1.0.1 Bargad.TreeStorage View Source

Implements a :dets key value storage for persisting tree heads. This enables Bargad to support multiple trees.

Link to this section Summary

Functions

Deletes a tree with the specified key from :dets

Initializes :dets with a table :tree_table

Retrives a tree with the specified key from :dets

Saves a tree with the specified key in :dets

Link to this section Functions

Deletes a tree with the specified key from :dets.

Initializes :dets with a table :tree_table.

The table is created if it does not exist.

Retrives a tree with the specified key from :dets.

Saves a tree with the specified key in :dets.